fnss.topologies.datacenter.DatacenterTopology.clear — FNSS 0.1.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.0 documentation »

# fnss.topologies.datacenter.DatacenterTopology.clear

`DatacenterTopology.` `clear`()

  Remove all nodes and edges from the graph.

  This also removes the name, and all graph, node, and edge attributes.

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> G.clear()
      >>> G.nodes()
      []
      >>> G.edges()
      []

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.0 documentation »